SBtab - Table format for Systems Biology
========================================

This directory holds the files required for the build up of the pip installer. Its content is not required by SBtab users to employ SBtab or its tools. If you want to use SBtab, please go back to the main directory of the repository and check out the available options.
